from datetime import datetime
from os import path, sep
from pyrogram.types import InlineQueryResultArticle, InputTextMessageContent
from pyrogram.enums.chat_type import ChatType
from pyrogram.enums.chat_members_filter import ChatMembersFilter
from dateutil.relativedelta import relativedelta

from app import app, isAnAdmin
from modules.utils import configGet, jsonLoad, locale

@app.on_inline_query()
async def inline_answer(client, inline_query):

    if inline_query.chat_type in [ChatType.CHANNEL]:
        await inline_query.answer(
        results=[
            InlineQueryResultArticle(
                title=locale("title", "inline", "not_pm"),
                input_message_content=InputTextMessageContent(
                    locale("message_content", "inline", "not_pm")
                ),
                description=locale("description", "inline", "not_pm")
                )
            ]
        )
        return

    if (path.exists(f"{configGet('data', 'locations')}{sep}users{sep}{inline_query.from_user.id}.json") and jsonLoad(f"{configGet('data', 'locations')}{sep}users{sep}{inline_query.from_user.id}.json")["approved"]) or (await isAnAdmin(inline_query.from_user.id) is True):

        list_of_users = []
        async for m in app.get_chat_members(configGet("destination_group"), limit=configGet("inline_preview_count"), filter=ChatMembersFilter.SEARCH, query=inline_query.query):
            list_of_users.append(m)

        results = []

        applications = jsonLoad(f"{configGet('data', 'locations')}{sep}applications.json")

        for match in list_of_users:

            try:
                application_content = []
                i = 1
                for question in applications[str(match.user.id)]["application"]:
                    if i == 2:
                        age = relativedelta(datetime.now(), datetime.strptime(applications[str(match.user.id)]['application']['2'], '%d.%m.%Y'))
                        application_content.append(f"{locale('question'+str(i), 'message', 'question_titles')} {applications[str(match.user.id)]['application']['2']} ({age.years} р.)")
                    else:
                        application_content.append(f"{locale('question'+str(i), 'message', 'question_titles')} {applications[str(match.user.id)]['application'][question]}")
                    i += 1
            except KeyError:
                continue
            except FileNotFoundError:
                continue
            except TypeError:
                continue

            if match.user.photo != None:
                try:
                    if not path.exists(f'{configGet("cache", "locations")}{sep}avatars{sep}{match.user.photo.big_file_id}'):
                        print(f'Downloaded avatar {match.user.photo.big_file_id} of {match.user.id} and uploaded to {configGet("api")}/?avatar_id={match.user.photo.big_file_id}', flush=True)
                        await app.download_media(match.user.photo.big_file_id, file_name=f'{configGet("cache", "locations")}{sep}avatars{sep}{match.user.photo.big_file_id}')
                    results.append(
                        InlineQueryResultArticle(
                            title=str(match.user.first_name),
                            input_message_content=InputTextMessageContent(
                                locale("message_content", "inline", "user").format(match.user.first_name, match.user.username, "\n".join(application_content))
                            ),
                            description=locale("description", "inline", "user").format(match.user.first_name, match.user.username),
                            thumb_url=f'{configGet("api")}/?avatar_id={match.user.photo.big_file_id}'
                        )
                    )
                except ValueError:
                    results.append(
                        InlineQueryResultArticle(
                            title=str(match.user.first_name),
                            input_message_content=InputTextMessageContent(
                                locale("message_content", "inline", "user").format(match.user.first_name, match.user.username, "\n".join(application_content))
                            ),
                            description=locale("description", "inline", "user").format(match.user.first_name, match.user.username)
                        )
                    )
                except FileNotFoundError:
                    results.append(
                        InlineQueryResultArticle(
                            title=str(match.user.first_name),
                            input_message_content=InputTextMessageContent(
                                locale("message_content", "inline", "user").format(match.user.first_name, match.user.username, "\n".join(application_content))
                            ),
                            description=locale("description", "inline", "user").format(match.user.first_name, match.user.username)
                        )
                    )
            else:
                results.append(
                    InlineQueryResultArticle(
                        title=str(match.user.first_name),
                        input_message_content=InputTextMessageContent(
                            locale("message_content", "inline", "user").format(match.user.first_name, match.user.username, "\n".join(application_content))
                        ),
                        description=locale("description", "inline", "user").format(match.user.first_name, match.user.username)
                    )
                )

        await inline_query.answer(
            results=results,
            cache_time=10
        )

    else:
        await inline_query.answer(
        results=[
            InlineQueryResultArticle(
                title=locale("title", "inline", "forbidden"),
                input_message_content=InputTextMessageContent(
                    locale("message_content", "inline", "forbidden")
                ),
                description=locale("description", "inline", "forbidden")
                )
            ]
        )
        return